# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from picteus_ws_client.models.search_property_range import SearchPropertyRange
from typing import Optional, Set
from typing_extensions import Self

class SearchProperties(BaseModel):
    """
    Technical properties to match when searching for images, i.e. how an image search should operate regarding the image technical properties
    """ # noqa: E501
    width: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image width")
    height: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image height")
    weight_in_bytes: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image binary weight", alias="weightInBytes")
    creation_date: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image creation dates, expressed in milliseconds from 1970, January 1st", alias="creationDate")
    modification_date: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image modification dates, expressed in milliseconds from 1970, January 1st", alias="modificationDate")
    __properties: ClassVar[List[str]] = ["width", "height", "weightInBytes", "creationDate", "modificationDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of width
        if self.width:
            _dict['width'] = self.width.to_dict()
        # override the default output from pydantic by calling `to_dict()` of height
        if self.height:
            _dict['height'] = self.height.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight_in_bytes
        if self.weight_in_bytes:
            _dict['weightInBytes'] = self.weight_in_bytes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of creation_date
        if self.creation_date:
            _dict['creationDate'] = self.creation_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of modification_date
        if self.modification_date:
            _dict['modificationDate'] = self.modification_date.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "width": SearchPropertyRange.from_dict(obj["width"]) if obj.get("width") is not None else None,
            "height": SearchPropertyRange.from_dict(obj["height"]) if obj.get("height") is not None else None,
            "weightInBytes": SearchPropertyRange.from_dict(obj["weightInBytes"]) if obj.get("weightInBytes") is not None else None,
            "creationDate": SearchPropertyRange.from_dict(obj["creationDate"]) if obj.get("creationDate") is not None else None,
            "modificationDate": SearchPropertyRange.from_dict(obj["modificationDate"]) if obj.get("modificationDate") is not None else None
        })
        return _obj


