# flake8: noqa

# import apis into api package
from picteus_ws_client.api.administration_api import AdministrationApi
from picteus_ws_client.api.api_secret_api import ApiSecretApi
from picteus_ws_client.api.collection_api import CollectionApi
from picteus_ws_client.api.extension_api import ExtensionApi
from picteus_ws_client.api.image_api import ImageApi
from picteus_ws_client.api.image_attachment_api import ImageAttachmentApi
from picteus_ws_client.api.miscellaneous_api import MiscellaneousApi
from picteus_ws_client.api.repository_api import RepositoryApi
from picteus_ws_client.api.settings_api import SettingsApi

