# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.extension_generation_options import ExtensionGenerationOptions

class TestExtensionGenerationOptions(unittest.TestCase):
    """ExtensionGenerationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtensionGenerationOptions:
        """Test ExtensionGenerationOptions
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtensionGenerationOptions`
        """
        model = ExtensionGenerationOptions()
        if include_optional:
            return ExtensionGenerationOptions(
                id = 'extension-id',
                version = '1.0.0',
                name = 'My extension',
                description = 'Computes the embeddings of images.',
                author = 'John Doe',
                environment = 'python'
            )
        else:
            return ExtensionGenerationOptions(
                id = 'extension-id',
                version = '1.0.0',
                name = 'My extension',
                description = 'Computes the embeddings of images.',
                author = 'John Doe',
                environment = 'python',
        )
        """

    def testExtensionGenerationOptions(self):
        """Test ExtensionGenerationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
