# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_features import SearchFeatures

class TestSearchFeatures(unittest.TestCase):
    """SearchFeatures unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFeatures:
        """Test SearchFeatures
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFeatures`
        """
        model = SearchFeatures()
        if include_optional:
            return SearchFeatures(
                operator = 'or',
                conditions = [
                    picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                        type = nature, 
                        format = null, 
                        name = 'field', 
                        operator = null, 
                        value = Three women in a flower arrangement, )
                    ],
                features = picteus_ws_client.models.search_features.SearchFeatures(
                    operator = or, 
                    conditions = [
                        picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                            type = nature, 
                            format = null, 
                            name = 'field', 
                            operator = null, 
                            value = Three women in a flower arrangement, )
                        ], 
                    features = null, )
            )
        else:
            return SearchFeatures(
                operator = 'or',
                conditions = [
                    picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                        type = nature, 
                        format = null, 
                        name = 'field', 
                        operator = null, 
                        value = Three women in a flower arrangement, )
                    ],
        )
        """

    def testSearchFeatures(self):
        """Test SearchFeatures"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
