# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.image_attachment_api import ImageAttachmentApi


class TestImageAttachmentApi(unittest.TestCase):
    """ImageAttachmentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImageAttachmentApi()

    def tearDown(self) -> None:
        pass

    def test_imageattachment_create(self) -> None:
        """Test case for imageattachment_create

        Declares an image binary attachment
        """
        pass

    def test_imageattachment_download(self) -> None:
        """Test case for imageattachment_download

        Downloads an image binary attachment
        """
        pass


if __name__ == '__main__':
    unittest.main()
