# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.application_metadata_item_value import ApplicationMetadataItemValue

class TestApplicationMetadataItemValue(unittest.TestCase):
    """ApplicationMetadataItemValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationMetadataItemValue:
        """Test ApplicationMetadataItemValue
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationMetadataItemValue`
        """
        model = ApplicationMetadataItemValue()
        if include_optional:
            return ApplicationMetadataItemValue(
                schema_version = 1,
                id = '820hh5e0w5rmc0ctgw38b1t4pr',
                url = 'https://api.replicate.com/v1/predictions/820hh5e0w5rmc0ctgw38b1t4pr',
                model_tags = google/gemini-2.5-flash-image:2.5,
                software = 'comfyui',
                input_assets = [fb6af249-1061-48a0-9e47-026d7428d709],
                aspect_ratio = 1.7777,
                prompt = None
            )
        else:
            return ApplicationMetadataItemValue(
                schema_version = 1,
                model_tags = google/gemini-2.5-flash-image:2.5,
                prompt = None,
        )
        """

    def testApplicationMetadataItemValue(self):
        """Test ApplicationMetadataItemValue"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
