# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.instructions_prompt import InstructionsPrompt

class TestInstructionsPrompt(unittest.TestCase):
    """InstructionsPrompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InstructionsPrompt:
        """Test InstructionsPrompt
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InstructionsPrompt`
        """
        model = InstructionsPrompt()
        if include_optional:
            return InstructionsPrompt(
                kind = 'textual',
                value = None
            )
        else:
            return InstructionsPrompt(
                kind = 'textual',
                value = None,
        )
        """

    def testInstructionsPrompt(self):
        """Test InstructionsPrompt"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
