# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.image_summary import ImageSummary

class TestImageSummary(unittest.TestCase):
    """ImageSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageSummary:
        """Test ImageSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageSummary`
        """
        model = ImageSummary()
        if include_optional:
            return ImageSummary(
                creation_date = 1725989551416,
                modification_date = 1760890442560,
                id = 'fb6af249-1061-48a0-9e47-026d7428d709',
                repository_id = '9aa0820f-6405-4b54-a01a-a6b56489a77f',
                parent_id = 'bf325375-e030-fccb-a009-17317c57477301234567891011121314151617181920212223242526272829303132333435',
                name = 'fileName.png',
                format = 'PNG',
                mime_type = 'image/jpeg',
                uri = 'file:///Users/me/image//path/fileName.png',
                url = 'file:///Users/me/image//path/fileName.png',
                source_url = 'https://static1.smartbear.co/swagger/media/assets/images/swagger_logo.svg',
                size_in_bytes = 0,
                dimensions = picteus_ws_client.models.image_dimensions.ImageDimensions(
                    width = 1, 
                    height = 1, ),
                file_dates = picteus_ws_client.models.dates.Dates(
                    creation_date = 1725989551416, 
                    modification_date = 1760890442560, )
            )
        else:
            return ImageSummary(
                creation_date = 1725989551416,
                modification_date = 1760890442560,
                id = 'fb6af249-1061-48a0-9e47-026d7428d709',
                repository_id = '9aa0820f-6405-4b54-a01a-a6b56489a77f',
                name = 'fileName.png',
                format = 'PNG',
                mime_type = 'image/jpeg',
                uri = 'file:///Users/me/image//path/fileName.png',
                url = 'file:///Users/me/image//path/fileName.png',
                size_in_bytes = 0,
                dimensions = picteus_ws_client.models.image_dimensions.ImageDimensions(
                    width = 1, 
                    height = 1, ),
                file_dates = picteus_ws_client.models.dates.Dates(
                    creation_date = 1725989551416, 
                    modification_date = 1760890442560, ),
        )
        """

    def testImageSummary(self):
        """Test ImageSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
