# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.manifest_user_interface import ManifestUserInterface

class TestManifestUserInterface(unittest.TestCase):
    """ManifestUserInterface unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ManifestUserInterface:
        """Test ManifestUserInterface
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ManifestUserInterface`
        """
        model = ManifestUserInterface()
        if include_optional:
            return ManifestUserInterface(
                elements = [
                    picteus_ws_client.models.manifest_interface_element.ManifestInterfaceElement(
                        id = 'main', 
                        anchor = null, 
                        url = '/&+#WBZ+uaM8jc+;V+7EoE.bCKhzd.rB.6rp,F!l8%ZRp?NrzvDJz!H+iRsDgg-2B8%J0niUVDV0SFBOBi2v4qUxqdUaaSQt~6nrFg_a30', )
                    ]
            )
        else:
            return ManifestUserInterface(
                elements = [
                    picteus_ws_client.models.manifest_interface_element.ManifestInterfaceElement(
                        id = 'main', 
                        anchor = null, 
                        url = '/&+#WBZ+uaM8jc+;V+7EoE.bCKhzd.rB.6rp,F!l8%ZRp?NrzvDJz!H+iRsDgg-2B8%J0niUVDV0SFBOBi2v4qUxqdUaaSQt~6nrFg_a30', )
                    ],
        )
        """

    def testManifestUserInterface(self):
        """Test ManifestUserInterface"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
