# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchOriginNature(str, Enum):
    """
    Indicates how the search result entities should be sorted
    """

    """
    allowed enum values
    """
    REPOSITORIES = 'repositories'
    IMAGES = 'images'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchOriginNature from a JSON string"""
        return cls(json.loads(json_str))


