# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.api_secret_type import ApiSecretType

class TestApiSecretType(unittest.TestCase):
    """ApiSecretType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiSecretType(self):
        """Test ApiSecretType"""
        # inst = ApiSecretType()

if __name__ == '__main__':
    unittest.main()
