# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.image_api import ImageApi


class TestImageApi(unittest.TestCase):
    """ImageApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImageApi()

    def tearDown(self) -> None:
        pass

    def test_image_closest_embeddings_images(self) -> None:
        """Test case for image_closest_embeddings_images

        Gets the closest images to some embeddings attached to an extension
        """
        pass

    def test_image_closest_images(self) -> None:
        """Test case for image_closest_images

        Gets the closest images to the image following the embeddings of an extension
        """
        pass

    def test_image_compute_format(self) -> None:
        """Test case for image_compute_format

        Computes the format of an image
        """
        pass

    def test_image_convert(self) -> None:
        """Test case for image_convert

        Converts an image into a format
        """
        pass

    def test_image_delete(self) -> None:
        """Test case for image_delete

        Deletes an image
        """
        pass

    def test_image_download(self) -> None:
        """Test case for image_download

        Downloads an image
        """
        pass

    def test_image_ensure_tags(self) -> None:
        """Test case for image_ensure_tags

        Ensures that the tags are set on an image
        """
        pass

    def test_image_get(self) -> None:
        """Test case for image_get

        Gets an image
        """
        pass

    def test_image_get_all_embeddings(self) -> None:
        """Test case for image_get_all_embeddings

        Gets all the embeddings of an image
        """
        pass

    def test_image_get_all_features(self) -> None:
        """Test case for image_get_all_features

        Gets all the features of an image
        """
        pass

    def test_image_get_all_recipes(self) -> None:
        """Test case for image_get_all_recipes

        Gets all the recipes of an image
        """
        pass

    def test_image_get_all_tags(self) -> None:
        """Test case for image_get_all_tags

        Gets all the tags of an image
        """
        pass

    def test_image_get_embeddings(self) -> None:
        """Test case for image_get_embeddings

        Gets the embeddings of an image
        """
        pass

    def test_image_get_features(self) -> None:
        """Test case for image_get_features

        Gets all the features of an image for an extension
        """
        pass

    def test_image_get_metadata(self) -> None:
        """Test case for image_get_metadata

        Gets the metadata of an image
        """
        pass

    def test_image_get_tags(self) -> None:
        """Test case for image_get_tags

        Gets the tags of an image for an extension
        """
        pass

    def test_image_media_url(self) -> None:
        """Test case for image_media_url

        Gets an URL of the image
        """
        pass

    def test_image_modify(self) -> None:
        """Test case for image_modify

        Modifies an image
        """
        pass

    def test_image_search_features(self) -> None:
        """Test case for image_search_features

        Retrieves image features
        """
        pass

    def test_image_search_images(self) -> None:
        """Test case for image_search_images

        Retrieves image details
        """
        pass

    def test_image_search_media_url(self) -> None:
        """Test case for image_search_media_url

        Retrieves image media URLs
        """
        pass

    def test_image_search_summaries(self) -> None:
        """Test case for image_search_summaries

        Retrieves image summaries
        """
        pass

    def test_image_search_tags(self) -> None:
        """Test case for image_search_tags

        Retrieves image tags
        """
        pass

    def test_image_set_embeddings(self) -> None:
        """Test case for image_set_embeddings

        Sets the embeddings of an image
        """
        pass

    def test_image_set_features(self) -> None:
        """Test case for image_set_features

        Sets the features of an image
        """
        pass

    def test_image_set_tags(self) -> None:
        """Test case for image_set_tags

        Sets the tags of an image
        """
        pass

    def test_image_synchronize(self) -> None:
        """Test case for image_synchronize

        Synchronizes an image
        """
        pass

    def test_image_text_to_images(self) -> None:
        """Test case for image_text_to_images

        Gets the closest images to a text following the embeddings of an extension
        """
        pass


if __name__ == '__main__':
    unittest.main()
