# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_filter import SearchFilter

class TestSearchFilter(unittest.TestCase):
    """SearchFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFilter:
        """Test SearchFilter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFilter`
        """
        model = SearchFilter()
        if include_optional:
            return SearchFilter(
                criteria = picteus_ws_client.models.search_criteria.SearchCriteria(
                    formats = [PNG, JPEG], 
                    keyword = null, 
                    tags = null, 
                    features = null, 
                    properties = null, ),
                origin = None,
                sorting = picteus_ws_client.models.search_sorting.SearchSorting(
                    property = name, 
                    is_ascending = True, )
            )
        else:
            return SearchFilter(
        )
        """

    def testSearchFilter(self):
        """Test SearchFilter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
